@@ -11,11 +11,13 @@
 #include <qtabdialog.h>
 #include <qtextbrowser.h>
 
-#include "backend.h"
+#include "nvclock.h"
 
+class QLabel;
 class QSpinBox;
 class QCheckBox;
 class QComboBox;
+class QGroupBox;
 class QGridLayout;
 
 //------------------------------------------------------------------
@@ -35,25 +37,32 @@ private:
     QSpinBox    *spinCore, *spinMemory;
     QCheckBox   *checkDebug;
     QGridLayout *l;
+    QGroupBox   *cardInfo, *agpInfo;
 
-    struct card nvcard[10];
-    int  total_cards;
+    QLabel *labelGPUName, *labelBustype, *labelMemorySize, *labelMemoryType;
+    QLabel *labelAGPstatus, *labelSupAGPrates, *labelAGPrate;
+    QLabel *labelFWstatus, *labelSBAstatus;
+
+    //struct card nvcard[10];
 
     void addLabel(const QString &text, int yy);
+    void initCardInfo(int posy);
+    void initAGPInfo(int posy);
+
+    int  loadCardInfo();
+    int  loadAGPInfo();
+
     int  getCards();
 };
 
+extern int total_cards;
+
 //------------------------------------------------------------------
               
-class CNVclock : public QTabDialog
-{
+class CNVclock : public QTabDialog {
     Q_OBJECT
 
 public:
     CNVclock(QWidget *parent, char *name);
-
-protected:
-    QTextBrowser *initAbout();
-    QTextBrowser *initLinks();
 };
 #endif
